@@ -75,13 +75,11 @@ def stderrRedirected():
 
 ##
 # redirect output (escape characters during ROOT importation...)
-# The gymnastic with sys argv  is necessary to workaround for ROOT-7577
-argvTmp = sys.argv[:]
-sys.argv = []
 with stdoutRedirected():
     import ROOT
+# Silence Davix warning (see ROOT-7577)
+ROOT.PyConfig.IgnoreCommandLineOptions = True
 ROOT.gROOT.GetVersion()
-sys.argv = argvTmp
 
 import argparse
 import glob
@@ -303,7 +301,7 @@ def joinPathSplit(pathSplit):
     """
     return "/".join(pathSplit)
 
-MANY_OCCURENCE_WARNING = "Same name objects aren't supported: '{0}' of '{1}' won't be processed"
+MANY_OCCURENCE_WARNING = "Several versions of '{0}' are present in '{1}'. Only the most recent will be considered."
 
 def manyOccurenceRemove(pathSplitList,fileName):
     """
@@ -380,16 +378,13 @@ def patternToFileNameAndPathSplitList(pattern,wildcards = True):
     s3RootObjPattern = s3RootFilePattern+":*"
     gsRootFilePattern = "gs://*.root"
     gsRootObjPattern = gsRootFilePattern+":*"
-    rfioRootFilePattern = "rfio://*.root"
-    rfioRootObjPattern = rfioRootFilePattern+":*"
     pcmFilePattern = "*.pcm"
     pcmObjPattern = pcmFilePattern+":*"
 
     if fnmatch.fnmatch(pattern,httpRootObjPattern) or \
        fnmatch.fnmatch(pattern,xrootdRootObjPattern) or \
        fnmatch.fnmatch(pattern,s3RootObjPattern) or \
-       fnmatch.fnmatch(pattern,gsRootObjPattern) or \
-       fnmatch.fnmatch(pattern,rfioRootObjPattern):
+       fnmatch.fnmatch(pattern,gsRootObjPattern):
         patternSplit = pattern.rsplit(":", 1)
         fileName = patternSplit[0]
         objPattern = patternSplit[1]
@@ -399,8 +394,7 @@ def patternToFileNameAndPathSplitList(pattern,wildcards = True):
     if fnmatch.fnmatch(pattern,httpRootFilePattern) or \
        fnmatch.fnmatch(pattern,xrootdRootFilePattern) or \
        fnmatch.fnmatch(pattern,s3RootFilePattern) or \
-       fnmatch.fnmatch(pattern,gsRootFilePattern) or \
-       fnmatch.fnmatch(pattern,rfioRootFilePattern):
+       fnmatch.fnmatch(pattern,gsRootFilePattern):
         fileName = pattern
         pathSplitList = [[]]
         return [(fileName,pathSplitList)]
@@ -499,8 +493,7 @@ def getSourceDestListOptDict(parser, wildcards = True):
 # Several functions shared by rootcp, rootmv and rootrm
 
 TARGET_ERROR = "target '{0}' is not a directory"
-OMITTING_FILE_ERROR = "omitting file '{0}'"
-OMITTING_DIRECTORY_ERROR = "omitting directory '{0}'"
+OMITTING_ERROR = "omitting {0} '{1}'. Did you forget to specify the -r option for a recursive copy?"
 OVERWRITE_ERROR = "cannot overwrite non-directory '{0}' with directory '{1}'"
 
 def copyRootObject(sourceFile,sourcePathSplit,destFile,destPathSplit,oneSource,recursive,replace):
@@ -521,12 +514,12 @@ def copyRootObject(sourceFile,sourcePathSplit,destFile,destPathSplit,oneSource,r
     # OMITTING_FILE_ERROR or OMITTING_DIRECTORY_ERROR
     if not recursiveOption:
         if sourcePathSplit == []:
-            logging.warning(OMITTING_FILE_ERROR.format( \
-                sourceFile.GetName()))
+            logging.warning(OMITTING_ERROR.format( \
+                "file", sourceFile.GetName()))
             retcode += 1
         elif isDirectory(sourceFile,sourcePathSplit):
             logging.warning(OMITTING_DIRECTORY_ERROR.format( \
-                sourcePathSplit[-1]))
+                "directory", sourcePathSplit[-1]))
             retcode += 1
     # Run copyRootObjectRecursive function with the wish
     # to follow the unix copy behaviour
@@ -926,6 +919,7 @@ def _recursifTreePrinter(tree,indent):
             str(branch.GetTotBytes())]
         write(TREE_TEMPLATE.format(*rec,**dic),indent,end="\n")
         _recursifTreePrinter(branch,indent+2)
+    write("")
 
 def _prepareTime(time):
     """Get time in the proper shape
@@ -942,6 +936,21 @@ LONG_TEMPLATE = \
     isSpecial(ANSI_BOLD,"{0:{classWidth}}")+"{1:{timeWidth}}" + \
     "{2:{nameWidth}}{3:{titleWidth}}"
 
+def _printClusters(tree, indent):
+    clusterStart = 0
+    nTotClusters = 0
+    clusterIter = tree.GetClusterIterator(0)
+    clusterStart = clusterIter()
+    write(isSpecial(ANSI_BOLD, "Cluster INCLUSIVE ranges:\n"), indent)
+    while clusterStart < tree.GetEntries():
+        # here we list the inclusive ranges, therefore we have a -1
+        clustLine = " - # %d: [%d, %d]\n" % (
+            nTotClusters, clusterStart, clusterIter.GetNextEntry() - 1)
+        write(clustLine, indent)
+        nTotClusters += 1
+        clusterStart = clusterIter()
+    write(isSpecial(ANSI_BOLD,"The total number of clusters is %d\n" % nTotClusters), indent)
+
 def _rootLsPrintLongLs(keyList,indent,treeListing):
     """Print a list of Tkey in columns
     pattern : classname, datetime, name and title"""
@@ -971,6 +980,8 @@ def _rootLsPrintLongLs(keyList,indent,treeListing):
         if treeListing and isTreeKey(key):
             tree = key.ReadObj()
             _recursifTreePrinter(tree,indent+2)
+            tree = tree.GetTree()
+            _printClusters(tree, indent+2)
         if treeListing and isTHnSparseKey(key):
             hs = key.ReadObj()
             hs.Print('all')
